/******************************************************************************/
/* Agent2b - Vending Machine                                                  */
/******************************************************************************/
/* Nome: 8660_VMNSTP_GeraVenda_Mapa                                           */
/*                                                                            */
/* Descrio:                                                                 */
/*  Gera venda para o Mapa de Abastecimento.                                  */
/*                                                                            */
/* Criao:                                                                   */
/* 09/06/2002 - Adriano de Arajo                                             */
/******************************************************************************/
/* raise_application_error(-20501, '' , True);                                */
/* @C:\WEB_405\Sql\End_Conv\Oracle\8660_VMNSTPO_GRAVA_ESTOQUE_VMN.SQL         */
/******************************************************************************/

/******************************************************************************/
/* GRAVA O LANAMENTO DE ESTOQUE PARA OS ITENS DO MAPA                        */
/******************************************************************************/
CREATE OR REPLACE PROCEDURE GRAVA_ESTOQUE_VMN
   (P_IDTIPOTRANSF IN  TIPORETI.CDTIPORETI%TYPE,
    P_IDTIPOEQUIPA IN  MAPABASEV.IDSITMAPABAS%TYPE,
    P_PRXLANCESTQ  IN  LANCTOESTOQ.NRLANCESTQ%TYPE,
    P_CDFILIALMAP  IN  MAPABASEV.CDFILIAL%TYPE,
    P_NRMAPABASEV  IN  MAPABASEV.NRMAPABASEV%TYPE,
    P_DTMAPABASEV  IN  MAPABASEV.DTMAPABASEV%TYPE,
    P_NRVENDA      IN  VENDAVMN.NRVENDA%TYPE,
    P_CDFILIAL     IN  FILIAL.CDFILIAL%TYPE,
    P_CDALMOXARIFE IN  PARAMFILIAL.CDALMOXARIFE%TYPE,
    P_CDLOCALESTOQ IN  PARAMFILIAL.CDLOCALESTOQ%TYPE,
    P_CDOPERADOR   IN  OPERADOR.CDOPERADOR%TYPE,
    P_CDFILIORIG   IN  FILIAL.CDFILIAL%TYPE DEFAULT ' ',
    P_CDALMOXORIG  IN  PARAMFILIAL.CDALMOXARIFE%TYPE DEFAULT ' ',
    P_CDLOCALORIG  IN  PARAMFILIAL.CDLOCALESTOQ%TYPE DEFAULT ' ',
    P_OBSERVACAO   IN  LANCTOESTOQ.DSLANCESTQ%TYPE DEFAULT ' ')
IS
   V_CDFILIPROC   PARAMGERAL.CDFILIAL%TYPE;
   V_IDTPLANCTO   LANCTOESTOQ.IDTPLANCTO%TYPE;
   V_IDENTRSAIDOP LANCTOESTOQ.IDENTRSAIDOP%TYPE;
   V_CDTIPORETI   ITLANCTOEST.CDTIPORETI%TYPE;
   V_CDTIPORETIDE PARGERALVMN.CDTIPORETIDE%TYPE;
   V_CDTIPOOPER   LANCTOESTOQ.CDTIPOOPER%TYPE;
   V_IDLESTRECMAP LANCESTRECMA.IDLESTRECMAP%TYPE;
   V_DTFINAL      MAPABASEV.DTMAPABASEV%TYPE;
   V_IDTIPOMOVI   ITLANCTOEST.IDTIPOMOVI%TYPE;
   V_OBSERVACAO   LANCTOESTOQ.DSLANCESTQ%TYPE;   

   V_NRSEQITEM    NUMBER;
   V_QTPRODVEND   NUMBER;
   V_CTITELANCTO  NUMBER;
   V_VRCUSTOPROD  NUMBER;
   V_QTVENDGRANDT NUMBER;
   V_VRVENDGRANDT NUMBER;
BEGIN
   /* P_IDTIPOTRANSF:
     - SA: Sada para Abastecimento -> Almox. Rota
     - EA: Entrada de Abastecimento -> Almox. Mquina
     - SR: Sada de Retirada        -> Almox. Mquina
     - ER: Entrada de Retirada      -> Almox. Site (ParamFilial)
   */
   IF (P_IDTIPOTRANSF = 'EA') OR (P_IDTIPOTRANSF = 'ER') THEN
      V_IDTPLANCTO   := '2';
      V_IDENTRSAIDOP := 'E';
      V_IDTIPOMOVI   := '2';
   ELSE
      V_IDENTRSAIDOP := 'S';
      IF P_IDTIPOTRANSF = 'SR' THEN
         V_IDTPLANCTO   := '3';
         V_IDTIPOMOVI   := '3';
      ELSE
         V_IDTPLANCTO   := '4';
         V_IDTIPOMOVI   := '4';
      END IF;
   END IF;

   /*raise_application_error(-20501, P_OBSERVACAO , True);*/

   V_OBSERVACAO := SUBSTR('Venda '||P_NRVENDA||' Mapa '||P_NRMAPABASEV||'-'||P_OBSERVACAO,1,60);
   INSERT INTO LANCTOESTOQ
      (CDFILIAL, NRLANCESTQ, IDTPLANCTO, DTLANCESTQ,
       DSLANCESTQ, CDFILIMOVI, IDENTRSAIDOP)
   VALUES
      (P_CDFILIALMAP, P_PRXLANCESTQ, V_IDTPLANCTO, P_DTMAPABASEV,
       V_OBSERVACAO, P_CDFILIAL, V_IDENTRSAIDOP);

   V_NRSEQITEM := 1;
   IF P_IDTIPOEQUIPA = '0' THEN
      /*********************************************************************/
      /* LANAMENTO PARA OS ITENS DO MAPA                                  */
      FOR C_ITEMAPA IN
        (SELECT
            I.CDITMAPABAS,  I.CDPRODUTO   , I.QTABASITMAPA, I.QTFREPITMAPA, I.QTSALDITMAPA,
            I.VRPRITEMMAP,  I.VRPRITEMCMAP, I.CDPRODORIGTR, I.QTPERDITMAPA, I.QTRETIITMAPA,
            I.QTVENDITMAPA, I.QTFATUITMAPA, I.QTTESTITMAPA, I.CDTIPORETI,   P.CDPRODESTO,
            P.VRFATOCONV
         FROM PRODUTO P, ITEMAPABASEV I
         WHERE I.CDFILIAL    = P_CDFILIALMAP
           AND I.NRMAPABASEV = P_NRMAPABASEV
           AND P.CDPRODUTO   = I.CDPRODUTO) LOOP

         V_CDTIPORETI := '';
         V_CDTIPOOPER := '';
         IF (P_IDTIPOTRANSF = 'EA') OR (P_IDTIPOTRANSF = 'SA') THEN
            V_IDLESTRECMAP := 'A';
            V_QTPRODVEND   := C_ITEMAPA.QTABASITMAPA * C_ITEMAPA.VRFATOCONV;
            V_CDTIPOOPER   := '02';            
         ELSE
            V_IDLESTRECMAP := 'P';
            V_QTPRODVEND   := C_ITEMAPA.QTRETIITMAPA * C_ITEMAPA.VRFATOCONV;

            /* VERIFICA SE A RETIRADA  DE DEVOLUCAO */
            V_CDTIPORETI   := C_ITEMAPA.CDTIPORETI;
            SELECT CDTIPORETIDE INTO V_CDTIPORETIDE
            FROM PARGERALVMN;

            IF V_CDTIPORETIDE = V_CDTIPORETI THEN
               IF P_IDTIPOTRANSF = 'SR' THEN
                  V_CDTIPOOPER := '13';
               END IF;
            END IF;
         END IF;

         IF (V_QTPRODVEND > 0) THEN

            IF (P_IDTIPOTRANSF = 'EA') OR (P_IDTIPOTRANSF = 'ER') THEN
               V_VRCUSTOPROD  := CUSTO_PROD(P_CDFILIORIG, C_ITEMAPA.CDPRODESTO, 3,
                                            P_DTMAPABASEV, P_CDALMOXORIG, P_CDLOCALORIG);
            ELSE
               V_VRCUSTOPROD  := C_ITEMAPA.VRPRITEMMAP + C_ITEMAPA.VRPRITEMCMAP;
            END IF;

            INSERT INTO ITLANCTOEST
               (CDFILIAL,     NRLANCESTQ,  NRSEQUITEM,
                CDPRODUTO,    QTLANCTOEST, QTTOTLANCTO,
                CDPRODMOVI,   CDFILIMOVI,  CDALMOXARIFE,
                CDLOCALESTOQ, NRLOTEESTQ,  NRSUBLOTE,
                IDENTRSAIDOP, CDTIPORETI,  CDTIPOOPER,
                CDOPERADOR,   IDTIPOMOVI,  VRUNILANCTO,
                VRTOTLANCTO,  VRLANCTOEST, IDORDEMCLC)
            VALUES
               (P_CDFILIALMAP, P_PRXLANCESTQ, LPAD(TO_CHAR(V_NRSEQITEM), 4, '0'),
                C_ITEMAPA.CDPRODUTO,  V_QTPRODVEND, V_QTPRODVEND,
                C_ITEMAPA.CDPRODESTO, P_CDFILIAL,   P_CDALMOXARIFE,
                P_CDLOCALESTOQ, ' ', ' ',
                V_IDENTRSAIDOP, V_CDTIPORETI, V_CDTIPOOPER,
                P_CDOPERADOR,   V_IDTIPOMOVI, V_VRCUSTOPROD,
                V_QTPRODVEND * V_VRCUSTOPROD, V_VRCUSTOPROD,V_IDTIPOMOVI);

            INSERT INTO LANCESTITMAP
               (CDFILIAL, NRMAPABASEV, CDITMAPABAS,
                CDFILIMOVI, NRLANCESTQ, NRSEQUITEM,
                IDLESTITMAP)
            VALUES
               (P_CDFILIALMAP, P_NRMAPABASEV, C_ITEMAPA.CDITMAPABAS,
                P_CDFILIALMAP, P_PRXLANCESTQ, LPAD(TO_CHAR(V_NRSEQITEM), 4, '0'),
                V_IDLESTRECMAP);

            V_NRSEQITEM := V_NRSEQITEM + 1;
         END IF;
      END LOOP;
   ELSE
      /*********************************************************************/
      /* LANAMENTO PARA A COMPOSIO DOS ITENS DO MAPA                    */
      FOR C_RECITEMAPA IN
         (SELECT R.CDPRODUTO,  R.QTABASITREC, R.QTPERDITREC, R.CDTIPORETI,
                 P.CDPRODESTO, P.VRFATOCONV
          FROM PRODUTO P, RECITEMAPABA R
          WHERE (CDFILIAL    = P_CDFILIALMAP)
            AND (NRMAPABASEV = P_NRMAPABASEV)
            AND (P.CDPRODUTO = R.CDPRODUTO)) LOOP

         V_CDTIPORETI := '';
         V_CDTIPOOPER := '';
         IF (P_IDTIPOTRANSF = 'EA') OR (P_IDTIPOTRANSF = 'SA') THEN
            V_IDLESTRECMAP := 'A';
            V_QTPRODVEND   := C_RECITEMAPA.QTABASITREC * C_RECITEMAPA.VRFATOCONV;
         ELSE
            V_IDLESTRECMAP := 'P';
            V_QTPRODVEND   := C_RECITEMAPA.QTPERDITREC * C_RECITEMAPA.VRFATOCONV;

            /* VERIFICA SE A RETIRADA  DE DEVOLUCAO */
            V_CDTIPORETI := C_RECITEMAPA.CDTIPORETI;
            SELECT CDTIPORETIDE INTO V_CDTIPORETIDE
            FROM PARGERALVMN;

            IF V_CDTIPORETIDE = V_CDTIPORETI THEN
               IF P_IDTIPOTRANSF = 'SR' THEN
                  V_CDTIPOOPER := '13';
               END IF;
            END IF;
         END IF;

         IF (V_QTPRODVEND > 0) THEN

            IF (P_IDTIPOTRANSF = 'EA') OR (P_IDTIPOTRANSF = 'ER') THEN
               V_VRCUSTOPROD  := CUSTO_PROD(P_CDFILIORIG, C_RECITEMAPA.CDPRODESTO, 3,
                                            P_DTMAPABASEV, P_CDALMOXORIG, P_CDLOCALORIG);
            ELSE
               V_VRCUSTOPROD  := 0;
            END IF;

            INSERT INTO ITLANCTOEST
               (CDFILIAL,     NRLANCESTQ,  NRSEQUITEM,
                CDPRODUTO,    QTLANCTOEST, QTTOTLANCTO,
                CDPRODMOVI,   CDFILIMOVI,  CDALMOXARIFE,
                CDLOCALESTOQ, NRLOTEESTQ,  NRSUBLOTE,
                IDENTRSAIDOP, CDTIPORETI,  CDTIPOOPER,
                CDOPERADOR,   IDTIPOMOVI,  VRUNILANCTO,
                VRTOTLANCTO,  VRLANCTOEST, IDORDEMCLC)
            VALUES
               (P_CDFILIALMAP, P_PRXLANCESTQ, LPAD(TO_CHAR(V_NRSEQITEM), 4, '0'),
                C_RECITEMAPA.CDPRODUTO,  V_QTPRODVEND, V_QTPRODVEND,
                C_RECITEMAPA.CDPRODESTO, P_CDFILIAL,   P_CDALMOXARIFE,
                P_CDLOCALESTOQ, ' ', ' ',
                V_IDENTRSAIDOP, V_CDTIPORETI, V_CDTIPOOPER,
                P_CDOPERADOR,   V_IDTIPOMOVI, V_VRCUSTOPROD,
                V_QTPRODVEND * V_VRCUSTOPROD, V_VRCUSTOPROD,V_IDTIPOMOVI);

            INSERT INTO LANCESTRECMA
               (CDFILIAL,   NRMAPABASEV, CDPRODUTO,
                CDFILIMOVI, NRLANCESTQ,  NRSEQUITEM,
                IDLESTRECMAP)
            VALUES
               (P_CDFILIALMAP, P_NRMAPABASEV, C_RECITEMAPA.CDPRODUTO,
                P_CDFILIALMAP, P_PRXLANCESTQ, LPAD(TO_CHAR(V_NRSEQITEM), 4, '0'),
                V_IDLESTRECMAP);

            V_NRSEQITEM := V_NRSEQITEM + 1;
         END IF;
      END LOOP;
   END IF;

   SELECT COUNT(*) INTO V_CTITELANCTO
   FROM ITLANCTOEST
   WHERE CDFILIAL   = P_CDFILIALMAP
     AND NRLANCESTQ = P_PRXLANCESTQ;

   IF V_CTITELANCTO = 0 THEN
      DELETE FROM LANCTOESTOQ
      WHERE CDFILIAL   = P_CDFILIALMAP
        AND NRLANCESTQ = P_PRXLANCESTQ;
   ELSE
      IF SYSDATE > P_DTMAPABASEV THEN
         V_DTFINAL := SYSDATE;
      ELSE
         V_DTFINAL := P_DTMAPABASEV;
      END IF;
      ATUALIZA_ESTOQUE(P_CDFILIAL, P_DTMAPABASEV, V_DTFINAL, P_CDFILIALMAP, P_PRXLANCESTQ);
   END IF;
END;
/
/******************************************************************************/
/* GERA A VENDA E FAZ A TRANSFERENCIA DE ESTOQUE DOS ITENS                    */
/******************************************************************************/
CREATE OR REPLACE PROCEDURE GERAVENDA_MAPA
   (P_CDFILIAL     IN  MAPABASEV.CDFILIAL%TYPE,
    P_NRMAPABASEV  IN  MAPABASEV.NRMAPABASEV%TYPE,
    P_PRXVENDA     IN  VENDAVMN.NRVENDA%TYPE,
    P_PRXLANCESTQ  IN  LANCTOESTOQ.NRLANCESTQ%TYPE,
    P_CDOPERADOR   IN  OPERADOR.CDOPERADOR%TYPE,
    P_IDERRO       OUT MAPABASEV.IDZERAMAQUI%TYPE)
IS
   V_QTMAXPROITEP  ITEQUIPPRO.QTMAXPROITEP%TYPE;
   V_NRLANCESTQ    LANCTOESTOQ.NRLANCESTQ%TYPE;
   V_NRVENDA       VENDAVMN.NRVENDA%TYPE;
   V_IDSITMAPA     VARCHAR2(1);
   V_NRLANCVENDA   LANCTOESTOQ.NRLANCESTQ%TYPE;
   V_NRLANCTESTE   LANCTOESTOQ.NRLANCESTQ%TYPE;
   V_VRITEMVENDA   FLOAT;
   V_IDVENDA       VARCHAR2(1);
   V_DTFINAL       MAPABASEV.DTMAPABASEV%TYPE;

   /* CONTADORES */
   V_CTMAPA        NUMBER;
   V_CTITEMVENDA   NUMBER;
   V_QTABASTECE    NUMBER;
   V_QTRETIRADA    NUMBER;
   V_CTITEVENDA    NUMBER;
   V_CTMAPAPEND    NUMBER;
   V_CTITLANC      NUMBER;
   V_QTGRANDTOTEV  NUMBER;
   V_VRGRANDTOTEV  NUMBER;
   V_CTRECITEMAPA  NUMBER;
   V_CTPRODRECITE  NUMBER;

   /* ESTOQUE DE ORIGEM */
   V_CDFILIORIG  PARAMFILIAL.CDFILIAL%TYPE;
   V_CDALMOXORIG PARAMFILIAL.CDALMOXARIFE%TYPE;
   V_CDLOCALORIG PARAMFILIAL.CDLOCALESTOQ%TYPE;

   /* ESTOQUE DA MQUINA */
   V_CDFILIMOVI    EQUIPAPROD.CDFILIMOVI%TYPE;
   V_CDALMOXARIFE  EQUIPAPROD.CDALMOXARIFE%TYPE;
   V_CDLOCALESTOQ  EQUIPAPROD.CDLOCALESTOQ%TYPE;

   /* ESTOQUE DE DESTINO DEVOLUO */
   V_CDFILIDEST  PARAMFILIAL.CDFILIAL%TYPE;
   V_CDALMOXDEST PARAMFILIAL.CDALMOXARIFE%TYPE;
   V_CDLOCALDEST PARAMFILIAL.CDLOCALESTOQ%TYPE;

   /* DADOS DA ROTA */
   V_CDROTATRANS  ROTATRANS.CDROTATRANS%TYPE;

   /* DADOS DO MAPA */
   V_CDEQUIPPRO    MAPABASEV.CDEQUIPPRO%TYPE;
   V_DTMAPABASEV   MAPABASEV.DTMAPABASEV%TYPE;
   V_CDCLIENTE     MAPABASEV.CDCLIENTE%TYPE;
   V_CDFILIALCLIE  MAPABASEV.CDFILIAL%TYPE;
   V_IDZERAMAQUI   MAPABASEV.IDZERAMAQUI%TYPE;
   V_QTSALDOANT    ITEMAPABASEV.QTSALDITMAPA%TYPE;
   V_QTVENDITANT   ITEMAPABASEV.QTVENDITMAPA%TYPE;
   V_QTFATUITANT   ITEMAPABASEV.QTFATUITMAPA%TYPE;
   V_QTTESTITANT   ITEMAPABASEV.QTTESTITMAPA%TYPE;
   V_QTFATUITMAPA  ITEMAPABASEV.QTFATUITMAPA%TYPE;
   V_QTTESTITMAPA  ITEMAPABASEV.QTTESTITMAPA%TYPE;
   V_QTDETESTETOT  ITEMAPABASEV.QTTESTITMAPA%TYPE;
   V_QTSALDITMAPA  ITEMAPABASEV.QTSALDITMAPA%TYPE;
   V_IDTIPFILIMAP  MAPABASEV.IDTIPFILIMAP%TYPE;

   /* DADOS DO MQUINA */
   V_CDTIPOEQUI    TIPOEQUI.CDTIPOEQUI%TYPE;

   /* ITENS DA VENDA */
   V_QTPRODVEND    ITVENDAVMN.QTPRODVENDA%TYPE;
   V_CDGRUPPROD    ITVENDAVMN.CDGRUPPROD%TYPE;
   V_CDSUBGRPROD   ITVENDAVMN.CDSUBGRPROD%TYPE;

   V_OBSERVACAO    VARCHAR(60);

BEGIN
   /* GERAVENDA_MAPA                                                             */
   /* P_IDERRO:                                                                  */
   /*   A = VENDA GERADA COM SUCESSO                                             */
   /*   B = MAPA ANTERIOR NO APURADO                                            */
   /*   C = VENDA A VISTA MENOR QUE ZERO                                         */
   /*   D = VENDA A PRAZO MENOR QUE ZERO                                         */
   /*   E = NO EXISTE ESTOQUE PARA MQUINA                                      */
   /*   F = NO EXISTE ESTOQUE PARA A ROTA                                       */
   /*   G = NO EXISTE ESTOQUE CENTRAL                                           */
   /*   H = MOLA NO POSSUI CAPACIDADE MXIMA                                    */
   /*   I = ESTOQUE NEGATIVO                                                     */
   /*   J = NO H ALMOXARIFADO/LOCALIZAO PADRO CADASTRADOS PARA O SITE       */

   /* Dados do Mapa de Abastecimento */
   SELECT COUNT(*) INTO V_CTMAPA
   FROM MAPABASEV
   WHERE (CDFILIAL     = P_CDFILIAL)
     AND (NRMAPABASEV  = P_NRMAPABASEV)
     AND (IDSITMAPABAS = '2');

   IF V_CTMAPA > 0 THEN
      SELECT MAX(CDEQUIPPRO),   MAX(CDCLIENTE),   MAX(DTMAPABASEV),
             MAX(CDFILIALCLIE), MAX(CDROTATRANS), MAX(IDTIPFILIMAP)
      INTO   V_CDEQUIPPRO,      V_CDCLIENTE,      V_DTMAPABASEV,
             V_CDFILIALCLIE,    V_CDROTATRANS,    V_IDTIPFILIMAP
      FROM   MAPABASEV
      WHERE (CDFILIAL     = P_CDFILIAL)
        AND (NRMAPABASEV  = P_NRMAPABASEV)
        AND (IDSITMAPABAS = '2');

      P_IDERRO := 'A';
      /* Verifica se existe algum mapa direfente de apurado, com data anterior
         ao mapa que est sendo apurado */
      SELECT COUNT(*) INTO V_CTMAPAPEND
      FROM MAPABASEV
      WHERE (CDEQUIPPRO   =  V_CDEQUIPPRO)
        AND (DTMAPABASEV  <  V_DTMAPABASEV)
        AND (IDSITMAPABAS <> '3');

      IF V_CTMAPAPEND > 0 THEN
         P_IDERRO    := 'B';
         V_IDSITMAPA := '4';
      ELSE
          /* BUSCA O ESTOQUE DA MQUINA */
         SELECT MAX(CDFILIMOVI), MAX(CDALMOXARIFE), MAX(CDLOCALESTOQ), MAX(CDTIPOEQUI)
         INTO   V_CDFILIMOVI, V_CDALMOXARIFE, V_CDLOCALESTOQ, V_CDTIPOEQUI
         FROM   EQUIPAPROD
         WHERE (CDEQUIPPRO = V_CDEQUIPPRO);

         IF V_CDALMOXARIFE IS NULL THEN
            P_IDERRO    := 'E';
            V_IDSITMAPA := '4';
         ELSE
            /* BUSCA O ESTOQUE DO SITE, SE NO EXISTIR BUSCA O DA ROTA */
            IF V_IDTIPFILIMAP = '1' THEN
               SELECT MAX(CDFILIAL), MAX(CDALMOXARIFE), MAX(CDLOCALESTOQ)
               INTO   V_CDFILIORIG, V_CDALMOXORIG, V_CDLOCALORIG
               FROM   PARAMFILIAL
               WHERE (CDFILIAL = V_CDFILIALCLIE);

               V_CDFILIDEST  := V_CDFILIORIG;
               V_CDALMOXDEST := V_CDALMOXORIG;
               V_CDLOCALDEST := V_CDLOCALORIG;

               IF V_CDLOCALORIG IS NULL THEN
                  P_IDERRO    := 'J';
                  V_IDSITMAPA := '4';
               END IF;

            ELSE
               SELECT MAX(CDFILIAL), MAX(CDALMOXARIFE), MAX(CDLOCALESTOQ)
               INTO   V_CDFILIORIG,  V_CDALMOXORIG,     V_CDLOCALORIG
               FROM   ROTATRANS
               WHERE  CDROTATRANS = V_CDROTATRANS;

               V_CDFILIDEST  := V_CDFILIORIG;
               V_CDALMOXDEST := V_CDALMOXORIG;
               V_CDLOCALDEST := V_CDLOCALORIG;

               IF V_CDLOCALORIG IS NULL THEN
                  P_IDERRO    := 'F';
                  V_IDSITMAPA := '4';
               END IF;

            END IF;

            /* o campo cdlocaldest  utilizado somente para devoluo e estas so
            enviadas sempre para o almoxarifado central da filiproc */
            IF V_CDLOCALDEST IS NULL THEN
               SELECT MAX(PF.CDFILIAL), MAX(PF.CDALMOXARIFE), MAX(PF.CDLOCALESTOQ)
               INTO   V_CDFILIDEST,  V_CDALMOXDEST,     V_CDLOCALDEST
               FROM PARAMGERAL PG, PARAMFILIAL PF
               WHERE PG.CDFILIAL = PF.CDFILIAL;

               IF V_CDALMOXDEST IS NULL THEN
                  P_IDERRO    := 'G';
                  V_IDSITMAPA := '4';
               END IF;
            END IF;
         END IF;
      END IF;

      IF P_IDERRO = 'A' THEN
         V_IDSITMAPA := '2';

         SELECT COUNT(*) INTO V_CTRECITEMAPA
         FROM RECITEMAPABA
         WHERE CDFILIAL    = P_CDFILIAL
           AND NRMAPABASEV = P_NRMAPABASEV;

         V_NRLANCESTQ := P_PRXLANCESTQ;
         IF V_IDSITMAPA <> '4' THEN
            /************************************************************************/
            /* TRANSFERENCIA DE ESTOQUE */
            IF V_CTRECITEMAPA > 0 THEN
               SELECT COUNT(QTABASITREC), COUNT(QTPERDITREC)
               INTO V_QTABASTECE, V_QTRETIRADA
               FROM RECITEMAPABA
               WHERE CDFILIAL    = P_CDFILIAL
                 AND NRMAPABASEV = P_NRMAPABASEV;

               /* TRANSFERENCIA DE ABASTECIMENTO SITE/ROTA -> MAQUINA */
               IF V_QTABASTECE > 0 THEN
                  V_OBSERVACAO := 'Sada Site/Rota(Abastecido)';
                  GRAVA_ESTOQUE_VMN('SA',          '1',           V_NRLANCESTQ,
                                    P_CDFILIAL,    P_NRMAPABASEV, V_DTMAPABASEV,
                                    P_PRXVENDA,    V_CDFILIORIG , V_CDALMOXORIG,
                                    V_CDLOCALORIG, P_CDOPERADOR , ' ',' ',' ',
                                    V_OBSERVACAO);

                  V_NRLANCESTQ := LPAD(TO_CHAR(TO_NUMBER(V_NRLANCESTQ) + 1), 10, '0');
                  V_OBSERVACAO := 'Entrada Mquina(Abastecido)';
                  GRAVA_ESTOQUE_VMN('EA',           '1',           V_NRLANCESTQ,
                                    P_CDFILIAL,     P_NRMAPABASEV, V_DTMAPABASEV,
                                    P_PRXVENDA,     V_CDFILIMOVI,  V_CDALMOXARIFE,
                                    V_CDLOCALESTOQ, P_CDOPERADOR,  V_CDFILIORIG,
                                    V_CDALMOXORIG,  V_CDLOCALORIG, V_OBSERVACAO);

                  V_IDSITMAPA := '3';
               END IF;

               /* RETIRADA DA MAQUINA */
               IF V_QTRETIRADA > 0 THEN
                  IF V_QTABASTECE > 0 THEN
                     V_NRLANCESTQ := LPAD(TO_CHAR(TO_NUMBER(V_NRLANCESTQ) + 1), 10, '0');
                  END IF;
                  V_OBSERVACAO := 'Sada Mquina(Retirado)';
                  GRAVA_ESTOQUE_VMN('SR',           '1',           V_NRLANCESTQ,
                                    P_CDFILIAL,     P_NRMAPABASEV, V_DTMAPABASEV,
                                    P_PRXVENDA,     V_CDFILIMOVI,  V_CDALMOXARIFE,
                                    V_CDLOCALESTOQ, P_CDOPERADOR , ' ',' ',' ',
                                    V_OBSERVACAO);

                  V_NRLANCESTQ := LPAD(TO_CHAR(TO_NUMBER(V_NRLANCESTQ) + 1), 10, '0');
                  V_OBSERVACAO := 'Entrada Site/Rota(Retirado)';
                  GRAVA_ESTOQUE_VMN('ER',           '1',           V_NRLANCESTQ,
                                    P_CDFILIAL,     P_NRMAPABASEV, V_DTMAPABASEV,
                                    P_PRXVENDA,     V_CDFILIDEST,  V_CDALMOXDEST,
                                    V_CDLOCALDEST,  P_CDOPERADOR,  V_CDFILIORIG,
                                    V_CDALMOXORIG,  V_CDLOCALORIG, V_OBSERVACAO);

                  V_IDSITMAPA := '3';
               END IF;
            ELSE    /*MAPA SEM COMPOSIO */
               SELECT COUNT(QTABASITMAPA), COUNT(QTRETIITMAPA)
               INTO V_QTABASTECE, V_QTRETIRADA
               FROM ITEMAPABASEV
               WHERE CDFILIAL    = P_CDFILIAL
                 AND NRMAPABASEV = P_NRMAPABASEV;
               /* TRANSFERENCIA DE ABASTECIMENTO SITE/ROTA -> MAQUINA */
               IF (V_QTABASTECE > 0) THEN
                  V_OBSERVACAO := 'Sada Site/Rota(Abastecido)';
                  GRAVA_ESTOQUE_VMN('SA',          '0',           V_NRLANCESTQ,
                                    P_CDFILIAL,    P_NRMAPABASEV, V_DTMAPABASEV,
                                    P_PRXVENDA,    V_CDFILIORIG,  V_CDALMOXORIG,
                                    V_CDLOCALORIG, P_CDOPERADOR , ' ',' ',' ',
                                    V_OBSERVACAO);

                  V_NRLANCESTQ := LPAD(TO_CHAR(TO_NUMBER(V_NRLANCESTQ) + 1), 10, '0');
                  V_OBSERVACAO := 'Entrada Mquina(Abastecido)';
                  GRAVA_ESTOQUE_VMN('EA',           '0',           V_NRLANCESTQ,
                                    P_CDFILIAL,     P_NRMAPABASEV, V_DTMAPABASEV,
                                    P_PRXVENDA,     V_CDFILIMOVI,  V_CDALMOXARIFE,
                                    V_CDLOCALESTOQ, P_CDOPERADOR,  V_CDFILIORIG,
                                    V_CDALMOXORIG,  V_CDLOCALORIG, V_OBSERVACAO);

                  V_IDSITMAPA := '3';
               END IF;

               /* RETIRADA DA MAQUINA */
               IF V_QTRETIRADA > 0 THEN
                  IF V_QTABASTECE > 0 THEN
                     V_NRLANCESTQ := LPAD(TO_CHAR(TO_NUMBER(V_NRLANCESTQ) + 1), 10, '0');
                  END IF;
                  V_OBSERVACAO := 'Sada Mquina(Retirado)';
                  GRAVA_ESTOQUE_VMN('SR',           '0',           V_NRLANCESTQ,
                                    P_CDFILIAL,     P_NRMAPABASEV, V_DTMAPABASEV,
                                    P_PRXVENDA,     V_CDFILIMOVI,  V_CDALMOXARIFE,
                                    V_CDLOCALESTOQ, P_CDOPERADOR , ' ',' ',' ',
                                    V_OBSERVACAO);

                  V_NRLANCESTQ := LPAD(TO_CHAR(TO_NUMBER(V_NRLANCESTQ) + 1), 10, '0');
                  V_OBSERVACAO := 'Entrada Site/Rota(Retirado)';
                  GRAVA_ESTOQUE_VMN('ER',           '0',           V_NRLANCESTQ,
                                    P_CDFILIAL,     P_NRMAPABASEV, V_DTMAPABASEV,
                                    P_PRXVENDA,     V_CDFILIDEST,  V_CDALMOXDEST,
                                    V_CDLOCALDEST,  P_CDOPERADOR,  V_CDFILIORIG,
                                    V_CDALMOXORIG,  V_CDLOCALORIG, V_OBSERVACAO);

                  V_IDSITMAPA := '3';
               END IF;
            END IF;
         END IF;

         /********************************************************************/
         /* INCLUSO DA VENDA */
         INSERT INTO VENDAVMN
            (CDFILIAL, NRVENDA, DTVENDAVMN, IDSITVENDA, VRVENDTESOU,
             CDFILIALCLIE, CDCLIENTE, NRMAPABASEV,CDEQUIPPRO)
         VALUES
            (P_CDFILIAL, P_PRXVENDA, V_DTMAPABASEV, '1', NULL,
             V_CDFILIALCLIE, V_CDCLIENTE, P_NRMAPABASEV, V_CDEQUIPPRO);

         /* BAIXA DO ESTOQUE - VENDA */
         V_NRLANCESTQ  := LPAD(TO_CHAR(TO_NUMBER(V_NRLANCESTQ) + 1), 10, '0');
         /*V_NRLANCVENDA := P_PRXLANCESTQ;*/
         V_NRLANCVENDA := V_NRLANCESTQ;
         V_OBSERVACAO  := SUBSTR('Venda '||P_PRXVENDA||' Mapa '||P_NRMAPABASEV||'-'||'Sada Mquina(Vendido)',1,60); 
         INSERT INTO LANCTOESTOQ
            (CDFILIAL, NRLANCESTQ, IDTPLANCTO, DTLANCESTQ,
             DSLANCESTQ, CDFILIMOVI, IDENTRSAIDOP)
         VALUES
            (P_CDFILIAL, V_NRLANCESTQ, '4', V_DTMAPABASEV,
             V_OBSERVACAO, V_CDFILIMOVI, 'S');


         /* VERIFICA SE EXISTE QTDE TESTE A SER BAIXADA */
         SELECT MAX(SUM(QTTESTITMAPA))
         INTO   V_QTDETESTETOT
         FROM   ITEMAPABASEV I
         WHERE  I.CDFILIAL     = P_CDFILIAL
           AND  I.NRMAPABASEV  = P_NRMAPABASEV
         GROUP BY I.CDFILIAL, I.NRMAPABASEV;

         V_NRLANCTESTE  := '';
         IF V_QTDETESTETOT > 0 THEN
            /* BAIXA DO ESTOQUE - TESTE */
            V_NRLANCESTQ := LPAD(TO_CHAR(TO_NUMBER(V_NRLANCESTQ) + 1), 10, '0');
            V_OBSERVACAO := SUBSTR('Venda '||P_PRXVENDA||' Mapa '||P_NRMAPABASEV||'-Sada Mquina(Teste)',1,60);            
            INSERT INTO LANCTOESTOQ
               (CDFILIAL, NRLANCESTQ, IDTPLANCTO, DTLANCESTQ,
                DSLANCESTQ, CDFILIMOVI, IDENTRSAIDOP)
            VALUES
               (P_CDFILIAL, V_NRLANCESTQ, '4', V_DTMAPABASEV,
                V_OBSERVACAO, V_CDFILIMOVI, 'S');

           /* V_NRLANCTESTE := P_PRXLANCESTQ;*/
            V_NRLANCTESTE := V_NRLANCESTQ;
         END IF;

         /************************************************************************/
         /* CLCULO DAS QUANTIDADES E INCLUSO DOS ITENS DA VENDA */
         V_QTPRODVEND  := 0;
         V_CTITEMVENDA := 1;
         FOR C_ITEMAPABASEV IN
           (SELECT
               I.CDITMAPABAS,  I.CDPRODUTO   , I.QTABASITMAPA, I.QTFREPITMAPA, I.QTSALDITMAPA,
               I.VRPRITEMMAP,  I.VRPRITEMCMAP, I.CDPRODORIGTR, I.QTPERDITMAPA, I.QTRETIITMAPA,
               I.QTVENDITMAPA, I.QTFATUITMAPA, I.QTTESTITMAPA, A.CDPRODESTO,   B.CDPRODESTO CDPRODESTORIG
            FROM PRODUTO A, PRODUTO B, ITEMAPABASEV I
            WHERE I.CDFILIAL     = P_CDFILIAL
              AND I.NRMAPABASEV  = P_NRMAPABASEV
              AND I.CDPRODUTO    = A.CDPRODUTO
              AND I.CDPRODORIGTR = B.CDPRODUTO) LOOP

            /* RETORNA A QUANTIDADE VENDIDA DO MAPA */
            QTVENDA_MAPA(P_CDFILIAL, P_NRMAPABASEV, C_ITEMAPABASEV.CDITMAPABAS,
                         V_QTPRODVEND, V_QTFATUITMAPA, V_QTTESTITMAPA,
                         V_QTGRANDTOTEV, V_VRGRANDTOTEV, V_IDVENDA, V_QTSALDITMAPA);

            /* INCLUSAO DOS ITENS DA VENDA */
            IF (V_QTPRODVEND < 0) OR (V_QTFATUITMAPA < 0) OR (V_IDVENDA <> 'A') THEN
               V_IDSITMAPA := 4;

               IF (V_IDVENDA = 'A') THEN
                  IF (V_QTPRODVEND < 0) THEN
                     P_IDERRO := 'C';
                  END IF;

                  IF (V_QTFATUITMAPA < 0) THEN
                     P_IDERRO := 'D';
                  END IF;
               ELSE

                  IF V_IDVENDA = 'B' THEN
                     P_IDERRO := 'H';
                  END IF;
                  IF V_IDVENDA = 'C' THEN
                     P_IDERRO := 'I';
                  END IF;
               END IF;
            ELSE
               SELECT MAX(CDGRUPPROD), MAX(CDSUBGRPROD) INTO V_CDGRUPPROD, V_CDSUBGRPROD
               FROM PRSUBGRPROD
               WHERE CDPRODUTO = C_ITEMAPABASEV.CDPRODUTO;

               INSERT INTO ITVENDAVMN
                  (CDFILIAL,    NRVENDA,      NRSEQITVENDA,
                   QTPRODVENDA, VRUNITVENDA,  VRUNITVENDAC,
                   CDPRODUTO,   CDGRUPPROD,   CDSUBGRPROD,
                   QTFATUVENDA, QTTESTVENDA)
               VALUES
                  (P_CDFILIAL,   P_PRXVENDA, LPAD(TO_CHAR(V_CTITEMVENDA), 3, '0'),
                   V_QTPRODVEND, NVL(C_ITEMAPABASEV.VRPRITEMMAP,0), NVL(C_ITEMAPABASEV.VRPRITEMCMAP,0),
                   C_ITEMAPABASEV.CDPRODUTO, V_CDGRUPPROD, V_CDSUBGRPROD, V_QTFATUITMAPA, V_QTTESTITMAPA);

               /* *************************************************************************************************************** */
               /* BAIXA ESTOQUE DO ITEM - VENDA */
               IF V_QTPRODVEND + V_QTFATUITMAPA > 0 THEN
                  V_VRITEMVENDA := (V_QTPRODVEND + V_QTFATUITMAPA) * (C_ITEMAPABASEV.VRPRITEMMAP + C_ITEMAPABASEV.VRPRITEMCMAP);
                  IF V_CTRECITEMAPA > 0 THEN
                     INSERE_SUBPRODMAN(P_CDFILIAL, V_NRLANCVENDA, '01',
                                       C_ITEMAPABASEV.CDPRODUTO,
                                       V_QTPRODVEND + V_QTFATUITMAPA, V_VRITEMVENDA, 0, V_VRITEMVENDA, 0,
                                       V_VRITEMVENDA, V_QTPRODVEND + V_QTFATUITMAPA, '4', V_DTMAPABASEV,
                                       C_ITEMAPABASEV.CDPRODESTO, V_CDALMOXARIFE, V_CDLOCALESTOQ);
                  ELSE
                     INSERT INTO ITLANCTOEST
                        (CDFILIAL,     NRLANCESTQ,  NRSEQUITEM,
                         CDPRODUTO,    QTLANCTOEST, QTTOTLANCTO,
                         CDPRODMOVI,   CDFILIMOVI,  CDALMOXARIFE,
                         CDLOCALESTOQ, NRLOTEESTQ,  NRSUBLOTE,
                         IDENTRSAIDOP, CDTIPOOPER,  CDOPERADOR,
                         IDTIPOMOVI,   VRUNILANCTO, VRTOTLANCTO,
                         VRLANCTOEST,  IDORDEMCLC)
                     VALUES
                        (P_CDFILIAL, V_NRLANCVENDA, LPAD(TO_CHAR(V_CTITEMVENDA), 4, '0'),
                         C_ITEMAPABASEV.CDPRODUTO,  V_QTPRODVEND + V_QTFATUITMAPA,  V_QTPRODVEND + V_QTFATUITMAPA,
                         C_ITEMAPABASEV.CDPRODESTO, V_CDFILIMOVI, V_CDALMOXARIFE,
                         V_CDLOCALESTOQ, ' ', ' ', 'S', '01', P_CDOPERADOR, '4', C_ITEMAPABASEV.VRPRITEMMAP + C_ITEMAPABASEV.VRPRITEMCMAP,
                         V_VRITEMVENDA, C_ITEMAPABASEV.VRPRITEMMAP + C_ITEMAPABASEV.VRPRITEMCMAP, '4');

                     INSERT INTO LANCESTITMAP
                        (CDFILIAL, NRMAPABASEV, CDITMAPABAS,
                         CDFILIMOVI, NRLANCESTQ, NRSEQUITEM,
                         IDLESTITMAP)
                     VALUES
                        (P_CDFILIAL, P_NRMAPABASEV, C_ITEMAPABASEV.CDITMAPABAS,
                         P_CDFILIAL, V_NRLANCVENDA, LPAD(TO_CHAR(V_CTITEMVENDA), 4, '0'), 'V');
                  END IF;
               END IF;

               /* BAIXA ESTOQUE DO ITEM - TESTE */
               IF (V_NRLANCTESTE <> ' ') AND (V_QTTESTITMAPA > 0) THEN
                  IF V_CTRECITEMAPA > 0 THEN
                     INSERE_SUBPRODMAN(P_CDFILIAL, V_NRLANCTESTE, '',C_ITEMAPABASEV.CDPRODUTO,
                                       V_QTTESTITMAPA, 0, 0, 0, 0, 0, V_QTTESTITMAPA, '4', V_DTMAPABASEV,
                                       C_ITEMAPABASEV.CDPRODESTO,V_CDALMOXARIFE, V_CDLOCALESTOQ);
                  ELSE
                     INSERT INTO ITLANCTOEST
                        (CDFILIAL,     NRLANCESTQ,  NRSEQUITEM,
                         CDPRODUTO,    QTLANCTOEST, QTTOTLANCTO,
                         CDPRODMOVI,   CDFILIMOVI,  CDALMOXARIFE,
                         CDLOCALESTOQ, NRLOTEESTQ,  NRSUBLOTE,
                         IDENTRSAIDOP, CDTIPOOPER,  CDOPERADOR,
                         IDTIPOMOVI,   VRUNILANCTO, VRTOTLANCTO,
                         VRLANCTOEST,  IDORDEMCLC)
                     VALUES
                        (P_CDFILIAL, V_NRLANCTESTE, LPAD(TO_CHAR(V_CTITEMVENDA), 4, '0'),
                         C_ITEMAPABASEV.CDPRODUTO,  V_QTTESTITMAPA,  V_QTTESTITMAPA,
                         C_ITEMAPABASEV.CDPRODESTO, V_CDFILIMOVI, V_CDALMOXARIFE,
                         V_CDLOCALESTOQ, ' ', ' ', 'S', '01', P_CDOPERADOR, '4', C_ITEMAPABASEV.VRPRITEMMAP + C_ITEMAPABASEV.VRPRITEMCMAP,
                         V_VRITEMVENDA, C_ITEMAPABASEV.VRPRITEMMAP+C_ITEMAPABASEV.VRPRITEMCMAP, '4');

                     INSERT INTO LANCESTITMAP
                        (CDFILIAL, NRMAPABASEV, CDITMAPABAS,
                         CDFILIMOVI, NRLANCESTQ, NRSEQUITEM,
                         IDLESTITMAP)
                     VALUES
                        (P_CDFILIAL, P_NRMAPABASEV, C_ITEMAPABASEV.CDITMAPABAS,
                         P_CDFILIAL, V_NRLANCTESTE, LPAD(TO_CHAR(V_CTITEMVENDA), 4, '0'), 'V');

                  END IF;
               END IF;
               /* FIM DA BAIXA DO ITEM DA VENDA */
               /* *************************************************************************************************************** */

               IF V_IDSITMAPA <> 4 THEN
                  V_IDSITMAPA := '3';
               END IF;

               V_CTITEMVENDA := V_CTITEMVENDA + 1;
            END IF;
         END LOOP;

         UPDATE VENDAVMN
         SET
            QTVENDGRANDT = V_QTGRANDTOTEV,
            VRVENDGRANDT = V_VRGRANDTOTEV
         WHERE CDFILIAL = P_CDFILIAL
           AND NRVENDA  = P_PRXVENDA;

         /************************************************************************/
         IF V_CTRECITEMAPA > 0 THEN
            /* VERIFICA SE FOI GERADA A SADA DO ESTOQUE PARA A VENDA */
            SELECT COUNT(*) INTO V_CTITLANC
            FROM ITLANCTOEST
            WHERE CDFILIAL = P_CDFILIAL
              AND NRLANCESTQ = V_NRLANCVENDA;

            IF V_CTITLANC > 0 THEN
               FOR C_ITLANC IN (
                  SELECT NRSEQUITEM, CDPRODUTO
                  FROM ITLANCTOEST
                  WHERE CDFILIAL   = P_CDFILIAL
                    AND NRLANCESTQ = V_NRLANCVENDA) LOOP

                  /* GRAVA O PRODUTO NA RECEITA DO MAPA CASO A COMPOSIO DO PRODUTO TENHA SIDO ALTERADA */
                  SELECT COUNT(CDPRODUTO) INTO V_CTPRODRECITE
                  FROM RECITEMAPABA
                  WHERE CDFILIAL    = P_CDFILIAL
                    AND NRMAPABASEV = P_NRMAPABASEV
                    AND CDPRODUTO   = C_ITLANC.CDPRODUTO;

                  IF V_CTPRODRECITE = 0 THEN
                     INSERT INTO RECITEMAPABA
                        (CDFILIAL, NRMAPABASEV, CDPRODUTO)
                     VALUES
                        (P_CDFILIAL, P_NRMAPABASEV, C_ITLANC.CDPRODUTO);
                  END IF;

                  INSERT INTO LANCESTRECMA
                     (CDFILIAL,   NRMAPABASEV, CDPRODUTO,
                      CDFILIMOVI, NRLANCESTQ,  NRSEQUITEM,
                      IDLESTRECMAP)
                  VALUES
                     (P_CDFILIAL, P_NRMAPABASEV, C_ITLANC.CDPRODUTO,
                      P_CDFILIAL, V_NRLANCVENDA, C_ITLANC.NRSEQUITEM, 'V');
               END LOOP;
            ELSE
               DELETE FROM ITLANCTOEST
               WHERE CDFILIAL   = P_CDFILIAL
                 AND NRLANCESTQ = V_NRLANCVENDA;
            END IF;

            /* VERIFICA SE FOI GERADA A SADA DO ESTOQUE PARA TESTE */
            SELECT COUNT(*) INTO V_CTITLANC
            FROM ITLANCTOEST
            WHERE CDFILIAL   = P_CDFILIAL
              AND NRLANCESTQ = V_NRLANCTESTE;

            IF V_CTITLANC > 0 THEN
               FOR C_ITLANC IN (
                  SELECT NRSEQUITEM, CDPRODUTO
                  FROM ITLANCTOEST
                  WHERE CDFILIAL   = P_CDFILIAL
                    AND NRLANCESTQ = V_NRLANCTESTE) LOOP

                  /* GRAVA O PRODUTO NA RECEITA DO MAPA CASO A COMPOSIO DO PRODUTO TENHA SIDO ALTERADA */
                  SELECT COUNT(CDPRODUTO) INTO V_CTPRODRECITE
                  FROM RECITEMAPABA
                  WHERE CDFILIAL    = P_CDFILIAL
                    AND NRMAPABASEV = P_NRMAPABASEV
                    AND CDPRODUTO   = C_ITLANC.CDPRODUTO;

                  IF V_CTPRODRECITE = 0 THEN
                     INSERT INTO RECITEMAPABA
                        (CDFILIAL, NRMAPABASEV, CDPRODUTO)
                     VALUES
                        (P_CDFILIAL, P_NRMAPABASEV, C_ITLANC.CDPRODUTO);
                  END IF;

                  INSERT INTO LANCESTRECMA
                     (CDFILIAL,   NRMAPABASEV, CDPRODUTO,
                      CDFILIMOVI, NRLANCESTQ,  NRSEQUITEM,
                      IDLESTRECMAP)
                  VALUES
                     (P_CDFILIAL, P_NRMAPABASEV, C_ITLANC.CDPRODUTO,
                      P_CDFILIAL, V_NRLANCTESTE, C_ITLANC.NRSEQUITEM, 'P');
               END LOOP;
            ELSE
               DELETE FROM ITLANCTOEST
               WHERE CDFILIAL   = P_CDFILIAL
                 AND NRLANCESTQ = V_NRLANCTESTE;
            END IF;
         END IF;

         IF SYSDATE > V_DTMAPABASEV THEN
            V_DTFINAL := SYSDATE;
         ELSE
            V_DTFINAL := V_DTMAPABASEV;
         END IF;

         ATUALIZA_ESTOQUE(V_CDFILIMOVI, V_DTMAPABASEV, V_DTFINAL, P_CDFILIAL, V_NRLANCVENDA);
         ATUALIZA_ESTOQUE(V_CDFILIMOVI, V_DTMAPABASEV, V_DTFINAL, P_CDFILIAL, V_NRLANCTESTE);

         IF V_IDSITMAPA = '4' THEN
            DELETE ITVENDAVMN
            WHERE CDFILIAL = P_CDFILIAL
              AND NRVENDA  = P_PRXVENDA;

            DELETE VENDAVMN
            WHERE CDFILIAL = P_CDFILIAL
              AND NRVENDA  = P_PRXVENDA;

            UPDATE MAPABASEV
            SET NRVENDA      = NULL,
                IDSITMAPABAS = '4'
            WHERE CDFILIAL    = P_CDFILIAL
              AND NRMAPABASEV = P_NRMAPABASEV;
         ELSE
            SELECT COUNT(*) INTO V_CTITEVENDA
            FROM ITVENDAVMN
            WHERE CDFILIAL = P_CDFILIAL
              AND NRVENDA  = P_PRXVENDA;

            IF V_CTITEVENDA = 0 THEN
               DELETE VENDAVMN
               WHERE CDFILIAL = P_CDFILIAL
                 AND NRVENDA  = P_PRXVENDA;

               V_NRVENDA   := NULL;
               V_IDSITMAPA := '4';
            ELSE
               V_NRVENDA   := P_PRXVENDA;
               V_IDSITMAPA := '3';
            END IF;

            UPDATE MAPABASEV
            SET NRVENDA      = V_NRVENDA,
                IDSITMAPABAS = V_IDSITMAPA
            WHERE CDFILIAL    = P_CDFILIAL
              AND NRMAPABASEV = P_NRMAPABASEV;
         END IF;
      END IF;
   END IF;
END;
/
